@@ -18,16 +18,17 @@ class Workflow(BaseModel):
     def __repr__(self):
         return f"<Workflow {self.project}.{self.name}>"
 
-    def to_dict(self):
+    def to_dict(self, with_payload=True):
         d = super().to_dict()
         d.update(
             {
                 "name": self.name,
-                "payload": self.payload,
                 "project": self.project,
                 "fullname": f"{self.project}.{self.name}",
                 "status": self.status.value,
                 "periodic": self.periodic,
             }
         )
+        if with_payload:
+            d["payload"] = self.payload
         return d
