@@ -5,7 +5,6 @@ from environs import Env
 
 
 HIDDEN_CONFIG = [
-    "DIRECTOR_ENABLE_DARK_THEME",
     "DIRECTOR_ENABLE_HISTORY_MODE",
     "DIRECTOR_REFRESH_INTERVAL",
     "DIRECTOR_API_URL",
@@ -34,7 +33,6 @@ class Config(object):
         env = Env()
         env.read_env(env_path)
 
-        self.ENABLE_DARK_THEME = env.bool("DIRECTOR_ENABLE_DARK_THEME", False)
         self.ENABLE_HISTORY_MODE = env.bool("DIRECTOR_ENABLE_HISTORY_MODE", False)
         self.ENABLE_CDN = env.bool("DIRECTOR_ENABLE_CDN", True)
         self.STATIC_FOLDER = env.str(
@@ -44,6 +42,12 @@ class Config(object):
         self.FLOWER_URL = env.str("DIRECTOR_FLOWER_URL", "http://127.0.0.1:5555")
         self.WORKFLOWS_PER_PAGE = env.int("DIRECTOR_WORKFLOWS_PER_PAGE", 1000)
         self.REFRESH_INTERVAL = env.int("DIRECTOR_REFRESH_INTERVAL", 30000)
+        self.REPO_LINK = env.str(
+            "DIRECTOR_REPO_LINK", "https://github.com/ovh/celery-director"
+        )
+        self.DOCUMENTATION_LINK = env.str(
+            "DIRECTOR_DOCUMENTATION_LINK", "https://ovh.github.io/celery-director"
+        )
 
         # Authentication
         self.AUTH_ENABLED = env.bool("DIRECTOR_AUTH_ENABLED", False)
